@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "24f73aa05624fc209da8f0f2689875aedeb584f0",
-  "branchName": "release-client-6.1.x",
-  "buildTime": "2024-07-18 10:36:53 GMT",
-  "buildVersion": "1.0.951",
+  "commitId": "7dd58c7eed20db09ecc931433ffffd31a7e940ed",
+  "branchName": "release-client-6.1.6",
+  "buildTime": "2024-07-26 03:01:56 GMT",
+  "buildVersion": "1.0.982",
   "css": [
     "@zoom/client-calendar-desktop/static/css/chunk-vendors.49e8f34d.css",
-    "@zoom/client-calendar-desktop/static/css/app.4022c6dd.css"
+    "@zoom/client-calendar-desktop/static/css/app.bd7c05bf.css"
   ],
   "js": [
     "@zoom/client-calendar-desktop/static/js/chunk-vendors.a7965a68.js",
-    "@zoom/client-calendar-desktop/static/js/app.38f5ad17.js"
+    "@zoom/client-calendar-desktop/static/js/app.fa7d841d.js"
   ],
   "key": "@zoom/client-calendar-desktop"
 };
